function [outputStruct] = makePaperPlots_submission2(figureNumbers)

if nargin==0
    plotInds = {'Fig. 1 - mean ages of zircon with different growth patterns' % 1
        'Fig. 2 - zircon spot and fragment ages' % 2
        'Fig. 3 - zircon spot & fragment ages variable U' % 3
        'Fig. 4 - zircon spot analyses growth duration vs. uncertainties' % 4
        'Fig. 5 - calculated mean age and zircon mass distributions' % 5
        'Fig. 6 - MC simulation of mean age distributions with armoring' % 6
        'Fig. 7 - MSWD estimates for num of samples for error vs. duration' % 7
        'Fig. 8 - Mean and 95% range for samples from gaussian distribution' % 8
        'Fig. 9 - Example Ages' % 9
        'Supplementary Figure 1 - zircon spot and fragment ages, variable aspect ratio' % 10
        };

    [tests2perform,confirmed] = listdlg('ListString',plotInds, 'PromptString', 'Select figures to make', 'ListSize', [300, 150]);
    figureNumbers = tests2perform;

    if confirmed==0
        disp('No additional processing requested, exiting')
        return
    end

end

if ismember(1, figureNumbers) %% simplified growth density functions + expected mean age

    figure;
    tiledlayout(1,2,'TileSpacing','compact')
    nexttile(1);
    hold on
    set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)
    t_n = 0:0.001:1;
    plot(t_n, ones(size(t_n)), 'LineWidth',1), % uniform
    plot(t_n, 2*t_n, 'LineWidth', 1) %increasing
    plot(t_n, 2-2*t_n, 'LineWidth', 1) % decreasing
    plot(t_n, betapdf(t_n, 5, 2), 'LineWidth', 1) % betadist
    plot(t_n, betapdf(t_n, 2, 5), 'LineWidth', 1) % betadist
    plot(t_n, 3*exp(-3*t_n)/(1-exp(-3)), 'LineWidth', 1) % exp. dist
    xlim([0, 1]); ylim([0 3])
    box on;
    axis square
    xlabel('Time')
    ylabel('Zircon Volume Growth Rate')

    nexttile(2);
    set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)
    hold on; box on;
    plot(t_n, (1+t_n)/2, 'LineWidth', 1) % uniform
    plot(t_n, 2/3*(t_n.^2+t_n+1)./(1+t_n), 'LineWidth', 1) % increasing
    plot(t_n, 1/3*(2*t_n+1), 'LineWidth', 1) % decreasing
    plot(t_n, 5/7*betacdf(t_n,6,2,"upper")./betacdf(t_n, 5, 2,"upper"), 'LineWidth', 1)
    plot(t_n, 2/7*betacdf(t_n,3,5,"upper")./betacdf(t_n, 2, 5,"upper"), 'LineWidth', 1)
    plot(t_n, (exp(-3*t_n).*(3*t_n+1)-4/exp(3))./(3*(exp(-3*t_n)-1/exp(3))), 'LineWidth', 1) % exp. dist

    axis square; box on
    %    set(gca, 'XDir', 'reverse')
    xlabel('Nucleation Time')
    ylabel('Volume-Weighted Zircon Age')
    ylim([0 1])


end % fig. 1

if ismember(2, figureNumbers) %% fig 2. - zircon spots and fragment ages
    % this just makes a simple example zircon with constant (volume) growth
    % from 1 to 0, constant zircon composition, with 5:1 aspect ratio.

    growthOptions = {'Uniform', 'Linear Increasing', 'Linear Decreasing'};

    [growthStyle,confirmed] = listdlg('ListString', growthOptions, 'PromptString', 'Select zircon growth', 'ListSize', [300, 150]);

    if confirmed==0
        disp('Ok, lets assume uniform growth')
        growthStyle=1;
    end

    zirconXtal_testIndConstGrowth(1,0,growthStyle,0,5,0,1e3,0,5);

end %% fig 2. - zircon spots and fragment ages

if ismember(3, figureNumbers)  %% fig 3 - zircon spots & fragments, var U

    prompt={'Input initial U concentration', 'Input final U concentration'};
    name='Input U concentration';
    numlines = [1 1];
    defaultanswer={'1', '1'};
    options.Resize = 'on'; options.Interpreter='tex'; options.WindowStyle='normal';

    answer=inputdlg(prompt,name,numlines',defaultanswer,options);

    if isempty(answer)
        warning('no U input given, assuming constant')
        Uconc = [1 1];
    elseif xor(isempty(answer{1}), isempty(answer{2}))
        warning('only one input value given, assuming constant')
        if isempty(answer{1})
            singleU = str2double(answer{2});
        else
            singleU = str2double(answer{1});
        end
        Uconc = [singleU singleU];
    else
        Uconc = [str2double(answer{1}) str2double(answer{2})];
    end

    zirconXtal_testIndConstGrowth(1,0,1,0,5,0,1e3,Uconc,3);
    zirconXtal_testIndConstGrowth(1,0,1,0,5,0,1e3,Uconc,4);

end %% fig. 3

if ismember(4, figureNumbers) %% fig. 4 - zircon spot analyses, growth duration + uncertainties

    [~, radiiTested, minMaxAges.Uni] = zirconXtal_test(1,0,1,0,5,0,1e3,0,7);
    %[~, ~, minMaxAges.Inc] = zirconXtal_test(1,0,2,0,5,0,1e3,0,7);
    %[~, ~, minMaxAges.Dec] = zirconXtal_test(1,0,3,0,5,0,1e3,0,7);


    radiiStrings = string(radiiTested);
    growthNames = {'Uni', 'Inc', 'Dec'};
    %fullNames = {'Uniform', 'Increasing', 'Decreasing'};

    figure;

    tiledlayout(2,1,'TileSpacing', 'compact', 'Padding', 'compact');

    nt1 = nexttile(1); makeNiceAxes(nt1);
    nt2 = nexttile(2); makeNiceAxes(nt2);

    lineStyles = {'-', '--', ':'};
    colorOrder = get(gca, 'ColorOrder');

    xlabel(nt2, {'Uncertainty relative to','true zircon growth duration'})
    ylabel(nt1, {'Probability of resolvable', 'core-rim age difference'})
    ylabel(nt2, {'Mean Resolved duration', 'relative to true growth duration'})

    legendNames = "";

    for n = 1
        tempSim = minMaxAges.(growthNames{n})';

        for m = 1:size(tempSim,1)

            if m == 1 && n == 1
                legendNames(1) = strcat("Spot size = ", radiiStrings(m), "x long axis");
            else
                legendNames(end+1) = strcat("Spot size = ", radiiStrings(m), "x long axis");
            end

            minMaxTemp = tempSim(m,:);
            realMeasDur = -diff(minMaxTemp);
            relUncertainty = 0.01:0.01:1;

            OneSigma = sqrt(2*relUncertainty.^2);
            TwoSigma = sqrt(2*(2*relUncertainty).^2);

            % this is calculated from the CDF of the normal distribution of the duration
            probResolvableDuration = 1 - 0.5*(1+erf(((TwoSigma)-realMeasDur)./(OneSigma*sqrt(2))));

            % can also calculate the mean dispersion of measurements where
            % dispersion was resolved, calculating the mean of a truncated
            % normal with same mean, std as above, but truncated at 2s:

            b = inf;
            a = TwoSigma;

            alpha = (a-realMeasDur)./OneSigma;
            beta1  = (b-realMeasDur)./OneSigma;

            phi_a = 1/sqrt(2*pi)*exp(-0.5*alpha.^2);
            phi_b = 1/sqrt(2*pi)*exp(-0.5*beta1.^2);

            PHI_a = 0.5*(1 + erf(alpha/sqrt(2)));
            PHI_b = 0.5*(1 + erf(beta1/sqrt(2)));

            resolvedDurationMean = realMeasDur + ((phi_a - phi_b)./(PHI_b - PHI_a)).*OneSigma;

            nexttile(1)
            pH(n,m) = plot(relUncertainty, probResolvableDuration, 'Color', colorOrder(m,:), 'LineStyle', lineStyles{n}, 'LineWidth', 1);
            
            nexttile(2)
            plot(relUncertainty, resolvedDurationMean, 'Color', colorOrder(m,:), 'LineStyle', lineStyles{n}, 'LineWidth', 1);
        end
    end

    l1 = legend(nt1, legendNames);
    l1.FontSize = 10; l1.EdgeColor = 'k';% l1.NumColumns = 2;

    axis(nt1, [0 1 0 1])

end %% fig 4. - zircon growth duration vs. uncertainties

if ismember(5, figureNumbers) %% fig. 5 - calculated zircon mass and mean age curves

    figure;
    tiledlayout(2,4, 'TileSpacing','compact', 'Padding', 'compact')
    tInc = 0.0001;
    t_n = tInc:tInc:(1-tInc);
    nexttile(1);
    hold on
    set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)

    meanAgeUniform = (1+t_n)/2;
    meanAgeInc = 2/3*(1-t_n.^3)./(1-t_n.^2);
    meanAgeDec = 1/3*(1-3*t_n.^2+2*t_n.^3)./((t_n-1).^2);
    meanAgeExp = (exp(-3*t_n).*(3*t_n+1)-4/exp(3))./(3*(exp(-3*t_n)-1/exp(3)));

    dHdtUniform = 0.5*ones(size(t_n));
    dHdtInc = 2*t_n.*(t_n+2)./(3*(t_n+1).^2);
    dHdtDec = 2/3*ones(size(t_n));
    dHdtExp =(exp(3*t_n+3).*(3*t_n-4)+exp(6))./((exp(3)-exp(3*t_n)).^2);

    uniformT0 = ones(size(t_n));
    incT0 = 2*t_n;
    decT0 = 2-2*t_n;
    betaT0 = betapdf(t_n, 2, 5);
    expT0 = exppdf(t_n, 1/3)/(1-exp(-3)); % need to correct for truncating the distribution on [0, 1]

    plot(t_n, uniformT0)
    plot([0 meanAgeDec(1) meanAgeDec], [0 0 uniformT0]./[1 1 dHdtDec])
    plot([0, meanAgeUniform(1), meanAgeUniform], [0, 0, uniformT0]./[1, dHdtUniform(1), dHdtUniform])
    plot([0 meanAgeInc(1), meanAgeInc], [0 0 uniformT0]./[1, 1 dHdtInc])
    plot([0 meanAgeExp(1), meanAgeExp], [0 0 uniformT0]./[1 1 dHdtExp])
    ylim([0 10])
    title('Uniform Nucleation Rate')
    axis square; box on
    ylabel('distribution of mean zircon ages')


    nexttile(2); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)

    plot(t_n, incT0)
    plot([0 meanAgeDec(1) meanAgeDec], [0 0 incT0]./[1 1 dHdtDec])
    plot([0,meanAgeUniform(1), meanAgeUniform], [0, 0, incT0]./[1, dHdtUniform(1), dHdtUniform])
    plot([0 meanAgeInc(1), meanAgeInc], [0 0 incT0]./[1, 1 dHdtInc])
    plot([0 meanAgeExp(1), meanAgeExp], [0 0 incT0]./[1 1 dHdtExp])
    ylim([0 10])
    title('Increasing Nucleation Rate')
    axis square; box on

    nexttile(3); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)

    plot(t_n, expT0)
    plot([0 meanAgeDec(1) meanAgeDec], [0 0 expT0]./[1 1 dHdtDec])
    plot([0,meanAgeUniform(1), meanAgeUniform], [0, 0, expT0]./[1, dHdtUniform(1), dHdtUniform])
    plot([0 meanAgeInc(1), meanAgeInc], [0 0 expT0]./[1, 1 dHdtInc])
    plot([0 meanAgeExp(1), meanAgeExp], [0 0 expT0]./[1, 1 dHdtExp])
    ylim([0 10])
    title('Decreasing Nucleation Rate')
    axis square; box on

    nexttile(4); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)

    plot(t_n, betaT0)
    plot([0 meanAgeDec(1) meanAgeDec], [0 0 betaT0]./[1 1 dHdtDec])
    plot([0,meanAgeUniform(1), meanAgeUniform], [0, 0, betaT0]./[1, dHdtUniform(1), dHdtUniform])
    plot([0 meanAgeInc(1), meanAgeInc], [0 0 betaT0]./[1, 1 dHdtInc])
    plot([0 meanAgeExp(1), meanAgeExp], [0 0 betaT0]./[1, 1 dHdtExp])
    ylim([0 10])
    axis square; box on
    title('Beta Dist. Nucleation Rate')


    nexttile(5); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)
    plot(t_n, uniformT0)
    plot(t_n, 8*(1-t_n).*(t_n-t_n.^2/2))
    plot(t_n, 2*t_n)
    plot(t_n, 3*t_n.^2)
    plot(t_n, 1/(1/3-4/3*exp(-3))*3*exp(-3*t_n).*t_n)
    axis square; box on
    ylabel('Normalized Zircon Volume Crystallization Rate')
    ylim([0 4])

    nexttile(6); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)
    plot(t_n, incT0)
    plot(t_n, 12*(1-t_n).*(t_n.^2))
    plot(t_n, 3*t_n.^2)
    plot(t_n, 4*t_n.^3)
    plot(t_n, 1/(1/18*(2-17/exp(3)))*(3/2)*t_n.^2.*exp(-3*t_n))
    axis square; box on
    ylim([0 4])

    nexttile(7); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)
    plot(t_n, expT0);
    plot(t_n, 9*(2-2*t_n).*(1-exp(-3*t_n))/(5-2*exp(-3)));
    plot(t_n, 3*(1-exp(-3*t_n))/(2+exp(-3)));
    plot(t_n, 9*(2*t_n).*(1-exp(-3*t_n))/(7+8*exp(-3)));
    plot(t_n, 3*exp(-3*t_n).*(1-exp(-3*t_n))/(((exp(3)-1)^2)/(2*exp(6))))
    axis square; box on
    ylim([0 4])

%     plot(t_n, decT0)
%     plot(t_n, 8*(1-t_n).*(t_n-t_n.^2/2))
%     plot(t_n, 3*(t_n-t_n.^2/2))
%     plot(t_n, 24/5*t_n.*(t_n-t_n.^2/2))
%     plot(t_n, 1/(2/9-7/(18*exp(3)))*3*exp(-3*t_n).*(t_n-(t_n.^2)/2))
%     axis square; box on
%     ylim([0 4])

    nexttile(8); hold on;     set(gca, 'XColor', 'k', 'YColor', 'k', 'FontSize', 14, 'LineWidth', 1)
    plot(t_n, betaT0)
    plot(t_n, 56/15*(1-t_n).*betainc(t_n,2,5))
    plot(t_n, 7/5*betainc(t_n, 2, 5))
    plot(t_n, 56/25*t_n.*betainc(t_n, 2, 5))
    plot(t_n, 243/(7*(10-103/exp(3)))*exp(-3*t_n).*t_n.^2.*(5*t_n.^4-24*t_n.^3+45*t_n.^2-40*t_n+15))
    axis square; box on
    ylim([0 4])

    l1 = legend({'instantaneous growth', 'decreasing growth', 'uniform growth', 'increasing growth', 'Exp. growth'}, 'Orientation','horizontal');
    l1.Layout.Tile = 'South';
end

if ismember(6, figureNumbers) %% fig. 6 - calculated zircon mean ages + armoring (updated, just uniform and beta)

    nucleationType = [1,3];
    growthType = 0:4;
    NucleationNames = {'Uniform','beta L'};
    growthNames = {'Instant', 'Uniform', 'Linear Increasing', 'Linear Decreasing'};
    armoringCurves = [{zeros(1e3+1,1)}, {ones(1e3+1,1)} {0:0.002:2}, {4*linspace(0,1,1e3+1).^3}];
    armoringNames = {'None', 'Uniform', 'Linear', 'Exponential'};

    figure;
    tiledlayout(length(armoringCurves), length(nucleationType), 'TileSpacing', 'compact', 'Padding', 'compact');

    numGrains = 1e5;

    for m = 1:length(armoringCurves)
        tempArmor = armoringCurves{m};        
        for n = 1:length(nucleationType)
            tempNucleation = nucleationType(n);
            nexttile
            for i = 1:length(growthType)
                tempGrowth = growthType(i);
                zirconXtal_testIndConstGrowth(numGrains, tempNucleation, tempGrowth, 2*tempArmor, 5, 0, 1e3, 0, 8, true); 
            end
        end
    end
            

end % 11

if ismember(7, figureNumbers) %% fig. 7 - MSWD vs. measurements, # of analyses

    [distType] = listdlg('ListString', {'Uniform', 'Binomial', 'Beta distribution', 'Constant', 'Trunc. Exponential', 'Truncated Normal'}, 'SelectionMode', 'Single', 'PromptString', 'Select underlying age distribution');
    
    numTests = 1e5;

    numSamples = [3 5 7 10 20 50];

    legendLabels = sprintf('n = %i_', numSamples);
    legendLabels = strsplit(legendLabels(1:end-1), '_');

    errDurationEsts = 0:0.01:1;

    percentNotNormal = zeros(length(numSamples), length(errDurationEsts));

    figure

    tiledlayout(1, 2, 'TileSpacing','compact','Padding','compact')
    nexttile(2); hold on
    for n = 1:length(numSamples)

        if distType==1
            avgDurrCorr = (numSamples(n)-1)/(numSamples(n)+1);
        elseif distType == 2
            avgDurrCorr = (2^numSamples(n)-2)/2^numSamples(n);
        elseif distType == 3
            empDurCorrections = [0.2697, 0.3678, 0.4239, 0.4767, 0.5639, 0.6536]; % I think there's a solution for this, but its knotty...
            avgDurrCorr = empDurCorrections(n);
        elseif distType == 4
            avgDurrCorr = 1;
        elseif distType == 5
            % avgDurrCorr = 1/3*sum(1./(1:(numSamples(n)-1))); this is the
            % actual solution for a non-truncated exponential
            empDurCorrections = [0.387, 0.527 0.607 0.681 0.7965 0.8975];
            avgDurrCorr = empDurCorrections(n);
            tempDist = makedist('Exponential', 1/3);
            tempDist = truncate(tempDist, 0, 1);
        elseif distType == 6
           % empDurCorrections = [0.377 0.514 0.591 0.664 0.778 0.882]; % sigma = 0.25
            empDurCorrections = [0.212 0.291 0.338 0.384 0.467 0.562]; % sigma = 0.125
            avgDurrCorr = empDurCorrections(n);
            tempDist = makedist('Normal', 0.5, 0.05);
            tempDist = truncate(tempDist, 0, 1);
        end


        for m = 1:length(errDurationEsts)

            if distType == 1
                tempAges = rand(numTests, numSamples(n));
            elseif distType == 2
                tempAges = randi([0 1], numTests, numSamples(n));
            elseif distType == 3
                tempAges = betarnd(2,5, numTests, numSamples(n));
            elseif distType == 4
                tempAges = ones(numTests, numSamples(n));
            elseif distType == 5
                tempAges = tempDist.random(numTests, numSamples(n));
            elseif distType == 6
                tempAges = tempDist.random(numTests, numSamples(n));                
            end

            tempErrs = randn(numTests, numSamples(n))*errDurationEsts(m);
            measuredAgeDist = tempAges+tempErrs;

            mswdCalc = 1/(numSamples(n)-1)*sum((measuredAgeDist-mean(measuredAgeDist,2)).^2/errDurationEsts(m)^2,2);
            mswdThreshold = 1 + 2*sqrt(2/(numSamples(n)-1));

            percentNotNormal(n,m) = 100*sum(mswdCalc>mswdThreshold)/length(mswdCalc);

            averageMeasRange(n,m) = mean(range(measuredAgeDist,2));

        end

%         if sum(percentNotNormal(n,:)>95)==0
%             notNormal95pct(n) = 0;
%         else
%             notNormal95pct(n) = find(percentNotNormal(n,:)>95,1,'last');
%         end
%  
%         if sum(percentNotNormal(n,:)>67)==0
%             notNormal67pct(n) = 0;
%         else
%             notNormal67pct(n) =  find(percentNotNormal(n,:)>67,1,'last');
%         end
% 
%         if sum(percentNotNormal(n,:)>50)==0
%             notNormal50pct(n) = 0;
%         else
%             notNormal50pct(n) = find(percentNotNormal(n,:)>50,1,'last');
%         end

        pH(n) = plot(errDurationEsts./averageMeasRange(n,:), percentNotNormal(n,:), 'LineWidth', 1);

    end

    set(gca, XColor='k', YColor='k', LineWidth=1,FontSize=14);
    axis square; box on
    xlabel('Uncertainty/Avg. Measured Duration'); ylabel('% non-Normal');
    title('Constant Uncertainty, Measured Durations')
    xlim([0 1])

    nexttile(1); hold on
    pH1 = plot(errDurationEsts, percentNotNormal, 'LineWidth', 1);

    set(gca, XColor='k', YColor='k', LineWidth=1,FontSize=14);
    axis square; box on
    xlabel('Uncertainty/True Duration'); ylabel('% non-Normal');
    l1 = legend(pH1, legendLabels);
    l1.Title.String = 'number of samples';
    l1.Layout.Tile = 'south';
    l1.Orientation  = 'horizontal';
    title('Constant Uncertainty, True Durations')

%    nexttile(3); hold on;
%    set(gca, XColor='k', YColor='k', LineWidth=1,FontSize=14);
%    axis square; box on

%     scatter(numSamples, errDurationEsts(notNormal50pct), 'filled')
%     scatter(numSamples, errDurationEsts(notNormal67pct), 'filled')
%     scatter(numSamples, errDurationEsts(notNormal95pct), 'filled')

% the next plots generate panels a-c. The actual pdfs for the convolution
% of beta and normal and truncated exponential and normal distributions are
% calculated analytical with Mathematica, but this approach gives nearly
% equivalent curves

figure; 
a1 = axes;
makeNiceAxes(a1);
errorScale = [1, 0.5 0.2 0.1 0.01];
x = -3:0.001:4;

if distType==1 % uniform
    for n = 1:length(errorScale) 
        plot(x, normcdf(x, 0, errorScale(n)) - normcdf(x, 1, errorScale(n)));
    end
elseif distType==2 % binomial/bernoulli
    for n = 1:length(errorScale) 
        plot(x, 0.5/(errorScale(n)*sqrt(2*pi))*(exp(-0.5*(x/errorScale(n)).^2)+exp(-0.5*((x-1)/errorScale(n)).^2)));
    end
elseif distType==3 % beta - this one i am just going to simulate numerically
    for n = 1:length(errorScale)
        betaDist = betarnd(2,5,1e6,1)+errorScale(n)*randn(1e6,1);
        plot(x, ksdensity(betaDist, x, 'Function','pdf'))
    end
elseif distType==4 % constant value
    for n = 1:length(errorScale)
        plot(x, 1/errorScale(n)/sqrt(2*pi)*exp(-0.5*(x/errorScale(n)).^2))
    end
elseif distType==5 % truncated exp, again numerically simulated
    for n = 1:length(errorScale)
        samplePts = tempDist.random(1e7,1)+errorScale(n)*randn(1e7,1);
        plot(x, ksdensity(samplePts, x, 'Function', 'pdf'))
    end
elseif distType==6 % truncated normal, again numerically simulated
    for n = 1:length(errorScale)
        samplePts = tempDist.random(1e7,1)+errorScale(n)*randn(1e7,1);
        plot(x, ksdensity(samplePts, x, 'Function', 'pdf'))
    end
end

end % Figure 7

if ismember(8, figureNumbers) %% mean and 95% of range for samples from gaussian distribution, 

    fTest = questdlg('Warning, the MC simulations required to make figure 8 can take a long time (hours). Do you want to proceed?',...
        'WARNING: Long calculation time', 'Yes', 'Cancel', 'Cancel');

    if strcmp(fTest, 'Cancel') || isempty(fTest)
        disp('Ok, lets not do that one right now.')
        return
    end

    numSims = 1e6;
    numSamples = 2:50;

    meanRange = zeros(size(numSamples));
    range95 = zeros(size(numSamples));
    medianRange = zeros(size(numSamples));

    for n = 1:length(numSamples)
        samples = randn(numSims, numSamples(n));
        ranges = range(samples, 2);
        meanRange(n) = mean(ranges);
        range95(n) = prctile(ranges, 95);
        medianRange(n) = median(ranges);
    end

    figure;
    tiledlayout(2,1, 'TileSpacing','compact', 'Padding','compact');

    
    aH = nexttile(1);
    makeNiceAxes(aH);

    s1 = scatter(numSamples, meanRange, 20, 'k');
    s2 = scatter(numSamples, range95, 20, 'k', 'filled');
    xlabel('Sample size')
    ylabel('Range relative to standard deviation of error')

    outputStruct.rangeMean = meanRange;
    outputStruct.range95 = range95;
    outputStruct.n = numSamples;
    outputStruct.numSims = numSims;
    
    p1 = plot(numSamples, -8.29*numSamples.^-0.19 + 8.43, 'k', 'LineWidth', 1);
    p2 = plot(numSamples, -6.45*numSamples.^-0.22 + 8.36, 'k', 'LineWidth', 1);

    legend([s1 p1 s2 p2], {'Simulated Mean', '8.43 - 8.29 n^{-0.19}', ...
        'Simulated 95^{th} percentile', '8.36 - 6.45 n^{-0.22}'}, 'Location', 'SE')

   %legend([s1 p1], {'Simulated Mean', '8.43 - 8.29 n^{-0.19}'}, 'Location', 'SE')

   %% panel B, repeats a lot of figure 7 but at much finer detail
   
   aH2 = nexttile(2);
   makeNiceAxes(aH2);

   distType = 1;

    numTests = 1e6;

    numSamples = 2:50;

    errDurationEsts = 0:0.001:1;

    percentNotNormal = zeros(length(numSamples), length(errDurationEsts));

    for n = 1:length(numSamples)

        if distType==1
            avgDurrCorr = (numSamples(n)-1)/(numSamples(n)+1);
        elseif distType == 2
            avgDurrCorr = (2^numSamples(n)-2)/2^numSamples(n);
        elseif distType == 3
            empDurCorrections = [0.2697, 0.3678, 0.4239, 0.4767, 0.5639, 0.6536]; % I think there's a solution for this, but its knotty...
            avgDurrCorr = empDurCorrections(n);
        elseif distType == 4
            avgDurrCorr = 1;
        end


        for m = 1:length(errDurationEsts)

            if distType == 1
                tempAges = rand(numTests, numSamples(n));
            elseif distType == 2
                tempAges = randi([0 1], numTests, numSamples(n));
            elseif distType == 3
                tempAges = betarnd(5,2, numTests, numSamples(n));
            elseif distType == 4
                tempAges = ones(numTests, numSamples(n));
            end

            tempErrs = randn(numTests, numSamples(n))*errDurationEsts(m);
            measuredAgeDist = tempAges+tempErrs;

            mswdCalc = 1/(numSamples(n)-1)*sum((measuredAgeDist-mean(measuredAgeDist,2)).^2/errDurationEsts(m)^2,2);
            mswdThreshold = 1 + 2*sqrt(2/(numSamples(n)-1));

            percentNotNormal(n,m) = 100*sum(mswdCalc>mswdThreshold)/length(mswdCalc);

        end

        notNormal95pct(n) = find(percentNotNormal(n,:)>95,1,'last');

    end
    
    scatter(numSamples, errDurationEsts(notNormal95pct), 'k', 'filled');
    hold on
    plot(numSamples, 3.34 - 3.39*numSamples.^-0.027, 'k', 'LineWidth', 1);
    legend({'M.C. estimate', '3.34 - 3.39 - n^{-0.027}'})

end % figure 8

if ismember(9, figureNumbers) %% figure 9, examples

    plotExampleAges(1:3);

end


if ismember(10, figureNumbers) %% supp. fig 1. - zircon spots and fragment ages
    % this  makes a simple example zircon with constant (volume) growth
    % from 1 to 0, constant zircon composition, with variable aspect ratio.

    growthOptions = {'Uniform', 'Linear Increasing', 'Linear Decreasing'};

    [growthStyle,confirmed] = listdlg('ListString', growthOptions, 'PromptString', 'Select zircon growth', 'ListSize', [300, 150]);

    [aspectRatio] = inputdlg('Please input long axis length relative to short axes.', 'Aspect Ratio', 1, {'5'});
    aspectRatioN = str2num(aspectRatio{1});
    if isnan(aspectRatioN) || length(aspectRatio)>1
        error('Incorrect Input')
    end

    if confirmed==0
        disp('Ok, lets assume uniform growth')
        growthStyle=1;
    end

    zirconXtal_testIndConstGrowth(1,0,growthStyle,0,aspectRatioN,0,1e3,0,5);

end %% Supplementary Figure 1. - zircon spots and fragment ages

end % main function End

function makeNiceAxes(axH)

set(axH, 'XColor', 'k', 'YColor', 'k', 'FontSize', 12, 'LineWidth', 1);
set(axH, 'Box', 'on');
hold(axH, 'on');
set(axH, 'PlotBoxAspectRatio', [1 1 1]);

end % makeNiceAxes
