function [] = plotExampleAges(samples2plot)

if nargin==0
    sampleList = {'GHR1 - Eddy et al., 2018'
        'SL17-10, Eddy et al., 2022'
        'TM-15A-11, Klein et al., 2021'};

    [samples2plot,confirmed] = listdlg('ListString',sampleList, 'PromptString', 'Select samples to plot', 'ListSize', [300, 150]);

    if confirmed==0
        disp('Must choose a sample to plot, try again.')
        return
    end

end

for i = 1:length(samples2plot)

    figure; hold on; axis square
    data2plot = loadData(samples2plot(i));

    [~, dataSort] = sort(data2plot.ages, 'descend');
    ages = data2plot.ages(dataSort);
    errs = data2plot.errors(dataSort);

    n = length(ages);

    vars = errs.^2;

    rmsErr2sig = 2*sqrt(sum(errs.^2)/n);

    wMean = sum(ages./vars)/sum(1./vars);
    wUnc  = 2*sqrt(1/sum(1./vars));

    MSWD = sum(((ages-wMean).^2)./vars)/(n-1);
    
    MSWDmin = 1-sqrt(2/(n-1));
    MSWDmax = 1+2*sqrt(2/(n-1));

    rangeMean = 8.43-8.29*n^-0.19;
    range95 = 8.36-6.45*n^-0.22;

    errorbar(ages, errs*2, 'k', 'LineStyle','none', 'CapSize',0, 'LineWidth', 3);
    a1 = gca;
    a1.XAxis.Visible = 'off';
    a1.YColor = 'k';
    a1.LineWidth = 1;
    a1.FontSize = 12;

    r1 = rectangle('Position', [0.5, wMean-rangeMean*(rmsErr2sig/2)/2, n, rangeMean*(rmsErr2sig/2)], 'FaceColor', [0.85 0.85 0.85], 'EdgeColor','none');
    uistack(r1,"bottom");

    xlim([0 1+n])

    plot([0.5 n+0.5], [wMean wMean], 'k', 'LineWidth', 1);
    plot([0.5 n+0.5], [wMean+wUnc, wMean-wUnc; wMean+wUnc wMean-wUnc], ':k', 'LineWidth', 1);
    plot([0.5 n+0.5], [wMean+rmsErr2sig/2, wMean-rmsErr2sig/2; wMean+rmsErr2sig/2, wMean-rmsErr2sig/2], '--k', 'LineWidth', 1);

    text0 = data2plot.label;
    text1 = sprintf('Weighted Mean = %2.5g±%0.2g Ma', wMean, wUnc);
    text2 = sprintf('Avg. measurement error = %0.2g Ma', rmsErr2sig);
    text3 = sprintf('MSWD = %1.3g | n = %i | max. MSWD = %1.3g', MSWD, n, MSWDmax);
    if MSWD<=MSWDmax
        maxDur = 3.34-3.39*n.^-0.027;
        text4 = sprintf('Maximum duration = %1.3g Ma', rmsErr2sig/2/maxDur);
    else
        text4 = sprintf('Minimum duration = %1.3g Ma', max(range(ages)-rangeMean*(rmsErr2sig/2), 0));
    end

    annotation("textbox", 'string', {text0; text1; text2; text3; text4}, 'Units', 'normalized', 'Position', [0.4 0.9 0.4 -0.2], 'HorizontalAlignment','right', 'LineStyle', 'none')

    set(gcf, 'Renderer', 'painters')
end




function [data2plot] = loadData(sampleNum)

switch sampleNum
    case 1
        data2plot.ages = [48.107
                          48.134
                          48.076
                          48.130
                          48.112
                          48.138
                          48.053
                          48.120
                          48.076
                          48.132
                          48.079
                          48.122
                          48.078
                          48.093
                          48.111
                          48.136
                          48.597
                          50.451
                          48.142
                          48.066
                          48.085
                          48.100
                          48.070
                          48.123
                          48.133
                          48.089
                          48.078];
        data2plot.errors=[0.035
                          0.036
                          0.046
                          0.034
                          0.050
                          0.061
                          0.047
                          0.068
                          0.049
                          0.038
                          0.035
                          0.038
                          0.039
                          0.062
                          0.088
                          0.026
                          0.026
                          0.098
                          0.075
                          0.059
                          0.044
                          0.044
                          0.047
                          0.044
                          0.045
                          0.045
                          0.051];
        data2plot.errors = data2plot.errors/2; % switch to 1 sigma

        data2plot.errors(data2plot.ages>48.5) = [];
        data2plot.ages(data2plot.ages>48.5) = [];

        data2plot.label = 'GHR1, Eddy et al., 2018';

    case 2
        data2plot.ages = [16.307
                        16.335
                        16.305
                        16.351
                        16.294
                        16.376
                        16.245
                        16.302
                        16.265
                        16.267
                        16.287
                        16.267
                        16.305];
        data2plot.errors = [0.066
                            0.061
                            0.052
                            0.036
                            0.025
                            0.053
                            0.031
                            0.054
                            0.062
                            0.057
                            0.07
                            0.093
                            0.072];
        data2plot.errors = data2plot.errors/2;
        
        data2plot.label = 'SL17-10, Eddy et al., 2022';
        
    case 3
%         data2plot.ages = [100.922
%                         100.72
%                         100.953
%                         101.096
%                         100.607
%                         100.987
%                         100.99
%                         100.62
%                         100.585
%                         100.66
%                         100.924
%                         100.917
%                         101.2
%                         101.002];
%         data2plot.errors = [0.088
%                             0.16
%                             0.058
%                             0.063
%                             0.085
%                             0.072
%                             0.17
%                             0.15
%                             0.061
%                             0.12
%                             0.061
%                             0.096
%                             0.11
%                             0.084];
        data2plot.ages = [100.62
100.809
100.835
100.687
100.847
100.69
100.616
100.751
100.669
100.73
100.623];

        data2plot.errors = [0.13
0.064
0.069
0.061
0.073
0.079
0.055
0.069
0.08
0.11
0.073];
        data2plot.errors = data2plot.errors/2;
        
        data2plot.label = 'TM-15A-11, Klein et al., 2021';
end

end


end